diff options
| author | Neal Coombes | 2017-06-23 11:31:17 -0500 |
|---|---|---|
| committer | Martin Hořeňovský | 2017-06-25 15:53:59 +0200 |
| commit | 396ecf6021b9c0e2b6799d091adf49b0182b180f (patch) | |
| tree | adac2932c16e45b0a7163f8df52452368b55ebd9 /projects/SelfTest/StringRef.tests.cpp | |
| parent | a6cdcd43aa24adf1e36edd5517a96feaeac18c25 (diff) | |
| download | catch3-396ecf6021b9c0e2b6799d091adf49b0182b180f.tar.gz | |
Cache std::ostringstream between assertions.
This is not thread safe, but I think that was already true of Catch.
The construction/destruction of the std::ostringstream is where the
vast majority of time is spent per assertion. A simple test of
100000000 CHECK()s is reduced from around 60s to 7.4s
Diffstat (limited to 'projects/SelfTest/StringRef.tests.cpp')
0 files changed, 0 insertions, 0 deletions